searchNodes=[{"doc":"RFC 4180 compliant CSV parsing and encoding for Elixir. Allows to specify other separators, so it could also be named: TSV, but it isn't.","ref":"CSV.html","title":"CSV","type":"module"},{"doc":"Decode a stream of comma-separated lines into a stream of tuples. Decoding errors will be inlined into the stream.OptionsThese are the options::separator – The separator token to use, defaults to ?,. Must be a codepoint (syntax: ? + (your separator)).:strip_fields – When set to true, will strip whitespace from cells. Defaults to false.:preprocessor – Which preprocessor to use: :lines (default) -&gt; Will preprocess line by line input respecting escape sequences :none -&gt; Will not preprocess input and expects line by line input with multiple line escape sequences aggregated to one line:validate_row_length – If set to false, will disable validation for row length. This will allow for rows with variable length. Defaults to true:escape_max_lines – How many lines to maximally aggregate for multiline escapes. Defaults to a 1000.:num_workers – The number of parallel operations to run when producing the stream.:worker_work_ratio – The available work per worker, defaults to 5. Higher rates will mean more work sharing, but might also lead to work fragmentation slowing down the queues.:headers – When set to true, will take the first row of the csv and use it as header values. When set to a list, will use the given list as header values. When set to false (default), will use no header values. When set to anything but false, the resulting rows in the matrix will be maps instead of lists.ExamplesConvert a filestream into a stream of rows in order of the given stream:iex&gt; &quot;../test/fixtures/docs/valid.csv&quot; iex&gt; |&gt; Path.expand(__DIR__) iex&gt; |&gt; File.stream! iex&gt; |&gt; CSV.decode iex&gt; |&gt; Enum.take(2) [ok: [&quot;a&quot;,&quot;b&quot;,&quot;c&quot;], ok: [&quot;d&quot;,&quot;e&quot;,&quot;f&quot;]]Errors will show up as error tuples:iex&gt; &quot;../test/fixtures/docs/escape-errors.csv&quot; iex&gt; |&gt; Path.expand(__DIR__) iex&gt; |&gt; File.stream! iex&gt; |&gt; CSV.decode iex&gt; |&gt; Enum.take(2) [ ok: [&quot;a&quot;,&quot;b&quot;,&quot;c&quot;], error: &quot;Escape sequence started on line 2 near \\&quot;d,e,f\\n\\&quot; did not terminate.\\n\\nEscape sequences are allowed to span up to 1000 lines. This threshold avoids collecting the whole file into memory when an escape sequence does not terminate. You can change it using the escape_max_lines option: https://hexdocs.pm/csv/CSV.html#decode/2&quot; ]Map an existing stream of lines separated by a token to a stream of rows with a header row:iex&gt; [&quot;a;b&quot;,&quot;c;d&quot;, &quot;e;f&quot;] iex&gt; |&gt; Stream.map(&amp;(&amp;1)) iex&gt; |&gt; CSV.decode(separator: ?;, headers: true) iex&gt; |&gt; Enum.take(2) [ ok: %{&quot;a&quot; =&gt; &quot;c&quot;, &quot;b&quot; =&gt; &quot;d&quot;}, ok: %{&quot;a&quot; =&gt; &quot;e&quot;, &quot;b&quot; =&gt; &quot;f&quot;} ]Map an existing stream of lines separated by a token to a stream of rows with a given header row:iex&gt; [&quot;a;b&quot;,&quot;c;d&quot;, &quot;e;f&quot;] iex&gt; |&gt; Stream.map(&amp;(&amp;1)) iex&gt; |&gt; CSV.decode(separator: ?;, headers: [:x, :y]) iex&gt; |&gt; Enum.take(2) [ ok: %{:x =&gt; &quot;a&quot;, :y =&gt; &quot;b&quot;}, ok: %{:x =&gt; &quot;c&quot;, :y =&gt; &quot;d&quot;} ]","ref":"CSV.html#decode/2","title":"CSV.decode/2","type":"function"},{"doc":"Decode a stream of comma-separated lines into a stream of tuples. Errors when decoding will get raised immediately.OptionsThese are the options::separator – The separator token to use, defaults to ?,. Must be a codepoint (syntax: ? + (your separator)).:strip_fields – When set to true, will strip whitespace from cells. Defaults to false.:preprocessor – Which preprocessor to use: :lines (default) -&gt; Will preprocess line by line input respecting escape sequences :none -&gt; Will not preprocess input and expects line by line input with multiple line escape sequences aggregated to one line:escape_max_lines – How many lines to maximally aggregate for multiline escapes. Defaults to a 1000.:validate_row_length – If set to false, will disable validation for row length. This will allow for rows with variable length. Defaults to true:num_workers – The number of parallel operations to run when producing the stream.:worker_work_ratio – The available work per worker, defaults to 5. Higher rates will mean more work sharing, but might also lead to work fragmentation slowing down the queues.:headers – When set to true, will take the first row of the csv and use it as header values. When set to a list, will use the given list as header values. When set to false (default), will use no header values. When set to anything but false, the resulting rows in the matrix will be maps instead of lists.ExamplesConvert a filestream into a stream of rows in order of the given stream:iex&gt; &quot;../test/fixtures/docs/valid.csv&quot; iex&gt; |&gt; Path.expand(__DIR__) iex&gt; |&gt; File.stream! iex&gt; |&gt; CSV.decode! iex&gt; |&gt; Enum.take(2) [[&quot;a&quot;,&quot;b&quot;,&quot;c&quot;], [&quot;d&quot;,&quot;e&quot;,&quot;f&quot;]]Errors will be raised:iex&gt; &quot;../test/fixtures/docs/row-length-errors.csv&quot; iex&gt; |&gt; Path.expand(__DIR__) iex&gt; |&gt; File.stream! iex&gt; |&gt; CSV.decode! iex&gt; |&gt; Enum.take(2) ** (CSV.RowLengthError) Row has length 3 - expected length 2 on line 2Map an existing stream of lines separated by a token to a stream of rows with a header row:iex&gt; [&quot;a;b&quot;,&quot;c;d&quot;, &quot;e;f&quot;] iex&gt; |&gt; Stream.map(&amp;(&amp;1)) iex&gt; |&gt; CSV.decode!(separator: ?;, headers: true) iex&gt; |&gt; Enum.take(2) [ %{&quot;a&quot; =&gt; &quot;c&quot;, &quot;b&quot; =&gt; &quot;d&quot;}, %{&quot;a&quot; =&gt; &quot;e&quot;, &quot;b&quot; =&gt; &quot;f&quot;} ]Map an existing stream of lines separated by a token to a stream of rows with a given header row:iex&gt; [&quot;a;b&quot;,&quot;c;d&quot;, &quot;e;f&quot;] iex&gt; |&gt; Stream.map(&amp;(&amp;1)) iex&gt; |&gt; CSV.decode!(separator: ?;, headers: [:x, :y]) iex&gt; |&gt; Enum.take(2) [ %{:x =&gt; &quot;a&quot;, :y =&gt; &quot;b&quot;}, %{:x =&gt; &quot;c&quot;, :y =&gt; &quot;d&quot;} ]","ref":"CSV.html#decode!/2","title":"CSV.decode!/2","type":"function"},{"doc":"Encode a table stream into a stream of RFC 4180 compliant CSV lines for writing to a file or other IO.OptionsThese are the options::separator – The separator token to use, defaults to ?,. Must be a codepoint (syntax: ? + (your separator)).:delimiter – The delimiter token to use, defaults to \\r\\n. Must be a string.ExamplesConvert a stream of rows with cells into a stream of lines:iex&gt; [~w(a b), ~w(c d)] iex&gt; |&gt; CSV.encode iex&gt; |&gt; Enum.take(2) [&quot;a,b\\r\\n&quot;, &quot;c,d\\r\\n&quot;]Convert a stream of rows with cells with escape sequences into a stream of lines:iex&gt; [[&quot;a\\nb&quot;, &quot;\\tc&quot;], [&quot;de&quot;, &quot;\\tf\\&quot;&quot;]] iex&gt; |&gt; CSV.encode(separator: ?\\t, delimiter: &quot;\\n&quot;) iex&gt; |&gt; Enum.take(2) [&quot;\\&quot;a\\\\nb\\&quot;\\t\\&quot;\\\\tc\\&quot;\\n&quot;, &quot;de\\t\\&quot;\\\\tf\\&quot;\\&quot;\\&quot;\\n&quot;]","ref":"CSV.html#encode/2","title":"CSV.encode/2","type":"function"},{"doc":"The Decoder CSV module sends lines of delimited values from a stream to the parser and converts rows coming from the CSV parser module to a consumable stream. In setup, it parallelises lexing and parsing, as well as different lexer/parser pairs as workers. The number of workers can be controlled via options.","ref":"CSV.Decoding.Decoder.html","title":"CSV.Decoding.Decoder","type":"module"},{"doc":"Decode a stream of comma-separated lines into a stream of rows. You can control the number of parallel work streams via the option :num_workers - default is the number of erlang schedulers times 3. The Decoder expects line by line input of valid csv lines with inlined escape sequences if you use it directly.OptionsThese are the options::separator – The separator token to use, defaults to ?,. Must be a codepoint (syntax: ? + (your separator)).:strip_fields – When set to true, will strip whitespace from fields. Defaults to false.:num_workers – The number of parallel operations to run when producing the stream.:worker_work_ratio – The available work per worker, defaults to 5. Higher rates will mean more work sharing, but might also lead to work fragmentation slowing down the queues.:headers – When set to true, will take the first row of the csv and use it as header values. When set to a list, will use the given list as header values. When set to false (default), will use no header values. When set to anything but false, the resulting rows in the matrix will be maps instead of lists.:replacement – The replacement string to use where lines have bad encoding. Defaults to nil, which disables replacement.ExamplesConvert a stream of lines with inlined escape sequences into a stream of rows:iex&gt; [&quot;a,b&quot;,&quot;c,d&quot;] ...&gt; |&gt; Stream.map(&amp;(&amp;1)) ...&gt; |&gt; CSV.Decoding.Decoder.decode ...&gt; |&gt; Enum.take(2) [ok: [&quot;a&quot;, &quot;b&quot;], ok: [&quot;c&quot;, &quot;d&quot;]]Map an existing stream of lines separated by a token to a stream of rows with a header row:iex&gt; [&quot;a;b&quot;,&quot;c;d&quot;, &quot;e;f&quot;] ...&gt; |&gt; Stream.map(&amp;(&amp;1)) ...&gt; |&gt; CSV.Decoding.Decoder.decode(separator: ?;, headers: true) ...&gt; |&gt; Enum.take(2) [ ok: %{&quot;a&quot; =&gt; &quot;c&quot;, &quot;b&quot; =&gt; &quot;d&quot;}, ok: %{&quot;a&quot; =&gt; &quot;e&quot;, &quot;b&quot; =&gt; &quot;f&quot;} ]Map an existing stream of lines separated by a token to a stream of rows with a header row with duplications:iex&gt; [&quot;a;b;b&quot;,&quot;c;d;e&quot;, &quot;f;g;h&quot;] ...&gt; |&gt; Stream.map(&amp;(&amp;1)) ...&gt; |&gt; CSV.Decoding.Decoder.decode(separator: ?;, headers: true) ...&gt; |&gt; Enum.take(2) [ ok: %{&quot;a&quot; =&gt; &quot;c&quot;, &quot;b&quot; =&gt; [&quot;d&quot;, &quot;e&quot;]}, ok: %{&quot;a&quot; =&gt; &quot;f&quot;, &quot;b&quot; =&gt; [&quot;g&quot;, &quot;h&quot;]} ]Map an existing stream of lines separated by a token to a stream of rows with a given header row:iex&gt; [&quot;a;b&quot;,&quot;c;d&quot;, &quot;e;f&quot;] ...&gt; |&gt; Stream.map(&amp;(&amp;1)) ...&gt; |&gt; CSV.Decoding.Decoder.decode(separator: ?;, headers: [:x, :y]) ...&gt; |&gt; Enum.take(2) [ ok: %{:x =&gt; &quot;a&quot;, :y =&gt; &quot;b&quot;}, ok: %{:x =&gt; &quot;c&quot;, :y =&gt; &quot;d&quot;} ]Decode a CSV string:iex&gt; csv_string = &quot;id,name\\r\\n1,Jane\\r\\n2,George\\r\\n3,John&quot; ...&gt; {:ok, out} = csv_string |&gt; StringIO.open ...&gt; out ...&gt; |&gt; IO.binstream(:line) ...&gt; |&gt; CSV.Decoding.Decoder.decode(headers: true) ...&gt; |&gt; Enum.map(&amp;(&amp;1)) [ ok: %{&quot;id&quot; =&gt; &quot;1&quot;, &quot;name&quot; =&gt; &quot;Jane&quot;}, ok: %{&quot;id&quot; =&gt; &quot;2&quot;, &quot;name&quot; =&gt; &quot;George&quot;}, ok: %{&quot;id&quot; =&gt; &quot;3&quot;, &quot;name&quot; =&gt; &quot;John&quot;} ]","ref":"CSV.Decoding.Decoder.html#decode/2","title":"CSV.Decoding.Decoder.decode/2","type":"function"},{"doc":"RFC 4180 compatible CSV lexer. Lexes tokens and sends them to the parser process.","ref":"CSV.Decoding.Lexer.html","title":"CSV.Decoding.Lexer","type":"module"},{"doc":"Lexes strings received from a sender (the decoder) and sends the resulting tokens to the parser process / the receiver.OptionsOptions get transferred from the decoder. They are::separator – The separator token to use, defaults to ?,. Must be a codepoint.:replacement – The replacement string to use where lines have bad encoding. Defaults to nil, which disables replacement.","ref":"CSV.Decoding.Lexer.html#lex/2","title":"CSV.Decoding.Lexer.lex/2","type":"function"},{"doc":"The CSV Parser module - parses tokens coming from the lexer and parses them into a row of fields.","ref":"CSV.Decoding.Parser.html","title":"CSV.Decoding.Parser","type":"module"},{"doc":"Parses tokens by receiving them from a sender / lexer and sending them to the given receiver process (the decoder).OptionsOptions get transferred from the decoder. They are::strip_fields – When set to true, will strip whitespace from fields. Defaults to false.","ref":"CSV.Decoding.Parser.html#parse/2","title":"CSV.Decoding.Parser.parse/2","type":"function"},{"doc":"The CSV lines preprocessor module - aggregates lines in a stream that are part of a common escape sequence.","ref":"CSV.Decoding.Preprocessing.Lines.html","title":"CSV.Decoding.Preprocessing.Lines","type":"module"},{"doc":"Aggregates the common escape sequences of a stream with the given separator.OptionsOptions get transferred from the decoder. They are::separator – The field separator:escape_max_lines – The maximum number of lines to collect in an escaped field","ref":"CSV.Decoding.Preprocessing.Lines.html#process/2","title":"CSV.Decoding.Preprocessing.Lines.process/2","type":"function"},{"doc":"The CSV none preprocessor module - input = output.","ref":"CSV.Decoding.Preprocessing.None.html","title":"CSV.Decoding.Preprocessing.None","type":"module"},{"doc":"Will pass on input unchanged","ref":"CSV.Decoding.Preprocessing.None.html#process/2","title":"CSV.Decoding.Preprocessing.None.process/2","type":"function"},{"doc":"The module defaults of CSV.","ref":"CSV.Defaults.html","title":"CSV.Defaults","type":"module"},{"doc":"The default number of workers used.","ref":"CSV.Defaults.html#num_workers/0","title":"CSV.Defaults.num_workers/0","type":"function"},{"doc":"The default worker / work ratio.","ref":"CSV.Defaults.html#worker_work_ratio/0","title":"CSV.Defaults.worker_work_ratio/0","type":"function"},{"doc":"Implement encoding for your data types.","ref":"CSV.Encode.html","title":"CSV.Encode","type":"protocol"},{"doc":"The encode function to implement, gets passed the data and env as a keyword list containing the currently used separator and delimiter.","ref":"CSV.Encode.html#encode/2","title":"CSV.Encode.encode/2","type":"function"},{"doc":"","ref":"CSV.Encode.html#t:t/0","title":"CSV.Encode.t/0","type":"type"},{"doc":"The Encoder CSV module takes a table stream and transforms it into RFC 4180 compliant stream of lines for writing to a CSV File or other IO.","ref":"CSV.Encoding.Encoder.html","title":"CSV.Encoding.Encoder","type":"module"},{"doc":"Encode a table stream into a stream of RFC 4180 compliant CSV lines for writing to a file or other IO.OptionsThese are the options::separator – The separator token to use, defaults to ?,. Must be a codepoint (syntax: ? + your separator token).:delimiter – The delimiter token to use, defaults to &quot;\\r\\n&quot;.:headers – When set to true, uses the keys of the first map as the first element in the stream. All subsequent elements are the values of the maps. When set to a list, will use the given list as the first element in the stream and order all subsequent elements using that list. When set to false (default), will use the raw inputs as elements. When set to anything but false, all elements in the input stream are assumed to be maps.ExamplesConvert a stream of rows with cells into a stream of lines:iex&gt; [~w(a b), ~w(c d)] iex&gt; |&gt; CSV.Encoding.Encoder.encode iex&gt; |&gt; Enum.take(2) [&quot;a,b\\r\\n&quot;, &quot;c,d\\r\\n&quot;]Convert a stream of maps into a stream of lines:iex&gt; [%{&quot;a&quot; =&gt; 1, &quot;b&quot; =&gt; 2}, %{&quot;a&quot; =&gt; 3, &quot;b&quot; =&gt; 4}] iex&gt; |&gt; CSV.Encoding.Encoder.encode(headers: true) iex&gt; |&gt; Enum.to_list() [&quot;a,b\\r\\n&quot;, &quot;1,2\\r\\n&quot;, &quot;3,4\\r\\n&quot;]Convert a stream of rows with cells with escape sequences into a stream of lines:iex&gt; [[&quot;a\\nb&quot;, &quot;\\tc&quot;], [&quot;de&quot;, &quot;\\tf\\&quot;&quot;]] iex&gt; |&gt; CSV.Encoding.Encoder.encode(separator: ?\\t, delimiter: &quot;\\n&quot;) iex&gt; |&gt; Enum.take(2) [&quot;\\&quot;a\\\\nb\\&quot;\\t\\&quot;\\\\tc\\&quot;\\n&quot;, &quot;de\\t\\&quot;\\\\tf\\&quot;\\&quot;\\&quot;\\n&quot;]","ref":"CSV.Encoding.Encoder.html#encode/2","title":"CSV.Encoding.Encoder.encode/2","type":"function"},{"doc":"Raised at runtime when the CSV encoding is invalid.","ref":"CSV.EncodingError.html","title":"CSV.EncodingError","type":"exception"},{"doc":"Raised at runtime when the CSV stream ends with unfinished escape sequences","ref":"CSV.EscapeSequenceError.html","title":"CSV.EscapeSequenceError","type":"exception"},{"doc":"Raised at runtime when the CSV has rows of variable length.","ref":"CSV.RowLengthError.html","title":"CSV.RowLengthError","type":"exception"},{"doc":"Raised at runtime when the CSV row has stray quotes.","ref":"CSV.StrayQuoteError.html","title":"CSV.StrayQuoteError","type":"exception"}]